#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Jul 25 14:53:13 2024

@author: fatihaltun
"""

import os
import subprocess

from setuptools import setup, find_packages


def create_mo_files():
    podir = "po"
    mo = []
    for po in os.listdir(podir):
        if po.endswith(".po"):
            os.makedirs("{}/{}/LC_MESSAGES".format(podir, po.split(".po")[0]), exist_ok=True)
            mo_file = "{}/{}/LC_MESSAGES/{}".format(podir, po.split(".po")[0], "eta-help.mo")
            msgfmt_cmd = 'msgfmt {} -o {}'.format(podir + "/" + po, mo_file)
            subprocess.call(msgfmt_cmd, shell=True)
            mo.append(("/usr/share/locale/" + po.split(".po")[0] + "/LC_MESSAGES",
                       ["po/" + po.split(".po")[0] + "/LC_MESSAGES/eta-help.mo"]))
    return mo


changelog = "debian/changelog"
if os.path.exists(changelog):
    head = open(changelog).readline()
    try:
        version = head.split("(")[1].split(")")[0]
    except:
        print("debian/changelog format is wrong for get version")
        version = "0.0.0"
    f = open("src/__version__", "w")
    f.write(version)
    f.close()

data_files = [
                 ("/usr/bin", ["eta-help"]),
                 ("/usr/share/applications",
                  ["data/tr.org.pardus.eta-help.desktop"]),
                 ("/usr/share/pardus/eta-help/ui",
                  ["ui/MainWindow.glade"]),
                 ("/usr/share/pardus/eta-help/src",
                  ["src/Main.py",
                   "src/MainWindow.py",
                   "src/Server.py",
                   "src/UserSettings.py",
                   "src/utils.py",
                   "src/__version__"]),
                 ("/usr/share/pardus/eta-help/data",
                  ["data/tr.org.pardus.eta-help-autostart.desktop",
                   "data/eta-help.svg",
                   "data/style.css",
                   "data/docs.png",
                   "data/faq.png",
                   "data/learn.png",
                   "data/etap-banner.png",
                   "data/etaplogo.png"]),
                 ("/etc/skel/.config/autostart",
                  ["data/tr.org.pardus.eta-help-autostart.desktop"]),
                 ("/usr/share/icons/hicolor/scalable/apps/",
                  ["data/eta-help.svg",
                   "data/eta-help-status.svg"])
             ] + create_mo_files()

setup(
    name="eta-help",
    version=version,
    packages=find_packages(),
    scripts=["eta-help"],
    install_requires=["PyGObject"],
    data_files=data_files,
    author="Fatih Altun",
    author_email="fatih.altun@pardus.org.tr",
    description="ETA Help application.",
    license="GPLv3",
    keywords="eta-help",
    url="https://github.com/pardus/eta-help",
)
